@@ -8,7 +8,7 @@ from aiohttp_client_cache.session import CachedSession
 
 from .Helpers.resourceAPI import ResourceAPI
 from .Helpers.utils import (JsonEncoder, add_github_token, parse_args,
-                            read_config_into, resolve_conflicts)
+                            parse_config, resolve_conflicts)
 from .parser import Parser
 from . import config
 
@@ -27,7 +27,7 @@ async def program():
         match args.cmd:
             case "gh-login": await add_github_token(session); return # type: ignore
             case "gh-logout": 
-                url = "https://github.com/settings/connections/applications/8011f22f502b091464de"
+                url = f"https://github.com/settings/connections/applications/{config.OAUTH_GITHUB_CLIENT_ID}"
                 print(f"You can revoke your access token by the following link: \n{url}"); return
             case "purge-cache":
                 if args.cache_web or args.cache_all: await session.cache.clear() # type: ignore
@@ -38,8 +38,8 @@ async def program():
         intermediate = await parser.parse()
         
         if version := args.modpack_version: intermediate.version = version
-        read_config_into(args.config, intermediate)
-        await resolve_conflicts(session, intermediate) # type: ignore
+        intermediate = parse_config(args.config, intermediate)
+        intermediate = await resolve_conflicts(session, intermediate) # type: ignore
 
         for format in args.formats:
 
